manex_odoo_repository
library
Classes
-
NetConnState
-
Provides interface to get current network connection state
and listen to events of going online/offline.
-
OdooEnvironment
-
-
OdooId
-
Represents Odoo database id.
It might be fake if record was created in offline mode.
-
OdooKv
-
Persistent key-value storage for offline work and performance.
-
OdooRecord
-
OdooRecord is immutable representation of Odoo record.
-
OdooRepository<R extends OdooRecord>
-
Base class of Odoo repository logic with RPC calls and local caching.
It sends stream events on record changes.
On read operation at first cached value is returned then async RPC call
is issued. When RPC response arrives stream gets update with fresh value.
-
OdooRpcCall
-
OdooRpcCall represents RPC call to Odoo database
It is used to store calls to persistent storage for later execution.
Enums
-
netConnState
-
Describes current network connection state